#########################
# CREATE TABLE COMMANDS #
#########################

CREATE TABLE build_info
(
        ens_db VARCHAR(50) NOT NULL PRIMARY KEY,
        db_name VARCHAR(50) NOT NULL,
        date_run DATETIME
);

CREATE INDEX location ON unigene (ug_cluster, ug_chr, ug_start, ug_end);

CREATE TABLE ugcount
(
	count_id INT auto_increment NOT NULL PRIMARY KEY,
	rep_id INT NOT NULL,
	cluster VARCHAR(20),
	sequence VARCHAR(20),
	length INT
);

CREATE INDEX ug_hits ON ugcount (rep_id,cluster,sequence,length);
CREATE INDEX length ON count (rep_id,length);

CREATE TABLE ugstats
(
	count_id INT auto_increment NOT NULL PRIMARY KEY,
	rep_id INT NOT NULL,
	count INT NOT NULL,
	min INT NOT NULL,
	max INT NOT NULL,
	mean DECIMAL(8,2) NOT NULL,
	sd DECIMAL(8,2) NULL
);

CREATE INDEX ug_stats ON ugstats (rep_id,count,min,max,mean,sd);
CREATE INDEX sd ON ugstats (rep_id,sd);

CREATE TABLE repeats
(
	rep_id INT auto_increment NOT NULL PRIMARY KEY,
	chr VARCHAR(4),
	start INT UNSIGNED,
	end INT UNSIGNED,
	period TINYINT UNSIGNED,
	unit VARCHAR(16),
	class INT,
	seq VARCHAR(255),
	length INT UNSIGNED,
	pvalue DECIMAL(8,6) NULL
);

CREATE INDEX r_total ON repeats (rep_id,chr,start,end,period,unit,seq,length);
CREATE INDEX r_common ON repeats (rep_id,period,unit,length); CREATE INDEX r_chr ON repeats (chr,start,end,period,unit,length);
CREATE INDEX r_total_period ON repeats (rep_id,period);
CREATE INDEX r_total_unit ON repeats (rep_id,unit);
CREATE INDEX r_total_length ON repeats (rep_id,length);
CREATE INDEX r_co_ords ON repeats (rep_id,chr,start,end); CREATE INDEX rapid ON repeats (period, length);

CREATE TABLE transcripts
(
	ts_id INT auto_increment NOT NULL PRIMARY KEY,
	rep_id INT NOT NULL,
	ens_ts VARCHAR(15),
	gene_location VARCHAR(20),
	pep VARCHAR(150) NULL,
	ens_id INT NOT NULL
);

CREATE INDEX t_common ON transcripts (rep_id,gene_location,pep,ens_id); 
CREATE INDEX t_pep ON transcripts (rep_id,gene_location); CREATE INDEX t_gene ON transcripts (rep_id,ens_id);

CREATE TABLE gc
(
	rep_id INT NOT NULL PRIMARY KEY,
	100_bp DECIMAL(7,6) NOT NULL,
	500_bp DECIMAL(7,6) NOT NULL,
	1000_bp DECIMAL(7,6) NOT NULL
);

CREATE INDEX gc_100 ON gc (rep_id,100_bp);
CREATE INDEX gc_500 ON gc (rep_id,500_bp);
CREATE INDEX gc_1000 ON gc (rep_id,1000_bp);

CREATE TABLE ens_db
(
	ens_id INT auto_increment NOT NULL PRIMARY KEY,
	ens_name VARCHAR(15) NOT NULL,
	name VARCHAR(15) NULL,
	description TEXT NULL,
	chr CHAR(2),
	start INT UNSIGNED,
	end INT UNSIGNED,
	strand CHAR(1)
);

CREATE INDEX ens_common ON ens_db (ens_id,ens_name,name); CREATE INDEX ens_lookup ON ens_db (ens_name,ens_id);

CREATE TABLE go
(
	go_id INT auto_increment NOT NULL PRIMARY KEY,
	ens_id INT NOT NULL,
	go_value VARCHAR(50) NOT NULL
);

CREATE INDEX go_go_value ON go (ens_id,go_value);

CREATE TABLE pdb
(
	pdb_id INT auto_increment NOT NULL PRIMARY KEY,
	ens_id INT NOT NULL,
	domain VARCHAR(20) NOT NULL
);

CREATE INDEX pdb_domain ON pdb (ens_id,domain);

CREATE TABLE mim
(
	mim_id INT auto_increment NOT NULL PRIMARY KEY,
	ens_id INT NOT NULL,
	mim_value VARCHAR(20) NOT NULL
);

CREATE INDEX mim_mim_value ON mim (ens_id,mim_value);

CREATE TABLE affy
(
	affy_id INT auto_increment NOT NULL PRIMARY KEY,
	ens_id INT NOT NULL,
	g_id INT NOT NULL
);

CREATE INDEX affy_id_ref ON affy (ens_id,g_id);

