SELECT DISTINCT u.rep_id, u.count, u.min, u.max, u.mean, u.sd, r.unit, r.length, t.gene_location, t.pep, e.name, e.description
FROM ugstats u, repeats r, transcripts t, ens_db e
WHERE u.sd > 2 AND u.rep_id = r.rep_id AND r.rep_id = t.rep_id AND t.ens_id = e.ens_id;

# how many above in genes expressed in brain?

SELECT DISTINCT u.rep_id, u.count, u.min, u.max, u.mean, u.sd, r.unit, r.length, t.gene_location, t.pep, e.name, e.description, g.tissue, g.call
FROM ugstats u, repeats r, transcripts t, ens_db e, affy a, genenote g
WHERE g.tissue = "Brain" AND g.call = "M" OR g.call = "P" AND e.ens_id = a.ens_id AND a.g_id = g.g_id AND u.sd > 2 AND u.rep_id = r.rep_id AND r.rep_id = t.rep_id AND t.ens_id = e.ens_id;

# How many unstable repeats exist in ensembl gene x

SELECT r.rep_id, r.chr, r.start, r.end, r.unit, r.class, r.length, t.gene_location, t.pep, e.name, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, transcripts t, ens_db e, ugstats u
WHERE e.name = "ENSG00000157168" AND e.ens_id = t.ens_id AND t.rep_id = r.rep_id 

# See what UniGene clusters the repeats within FOXP2 transcripts are hitting

SELECT DISTINCT r.chr, r.rep_id, r.start, r.end, r.unit, r.length, u.cluster, e.name
FROM repeats r, transcripts t, ens_db e, ugcount u
WHERE u.cluster = "Hs.306094" AND t.ens_id = e.ens_id AND r.rep_id = t.rep_id AND r.rep_id = u.rep_id;

# How many repeats are in exons or utrs?

SELECT DISTINCT r.rep_id, r.chr, r.start, r.end
FROM repeats r, transcripts t
WHERE r.rep_id = t.rep_id AND t.gene_location = "exon";

# Get all repeats within ensembl gene x

SELECT r.rep_id, r.chr, r.start, r.end, r.length, r.unit, r.class, t.gene_location, t.pep, e.name
FROM repeats r, transcripts t, ens_db e
WHERE r.rep_id = t.rep_id AND t.ens_id = e.ens_id AND e.ens_name = "ENSG00000130638";

# Get co-ords of all disease-associated repeats

SELECT r.rep_id, r.chr, r.start, r.end, d.short_name, d.full_name, d.name, d.ens_name, d.norm_min, d.norm_max, d.dis_min, d.dis_max, d.locus, d.anticipation
FROM repeats r, disease d
WHERE r.rep_id = d.rep_id;

# Which disease associated repeats are detected as unstable?

SELECT r.rep_id, r.unit, r.class, r.length, t.gene_location, t.pep, d.short_name, name, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, transcripts t, disease d, ugstats u
WHERE r.rep_id = t.rep_id AND d.rep_id = u.rep_id AND u.rep_id = r.rep_id;

# Get all unstable repeats

SELECT r.rep_id, r.unit, r.length, r.class, t.gene_location, t.pep, e.name, e.description, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, transcripts t, ens_db e, ugstats u
WHERE r.rep_id = t.rep_id AND t.ens_id = e.ens_id AND r.rep_id = u.rep_id

# Counts of unstable repeats by repeat unit size

SELECT r.rep_id, r.unit, r.length, r.class, t.gene_location, t.pep, e.name, e.description, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, transcripts t, ens_db e, ugstats u
WHERE r.rep_id = t.rep_id AND t.ens_id = e.ens_id AND r.rep_id = u.rep_id AND r.period = 16;

SELECT DISTINCT d.short_name AS disease_associated_repeats_not_unstable_in_UniGene_clusters
FROM repeats r, transcripts t, disease d, ugstats u
WHERE r.rep_id = t.rep_id AND d.rep_id = u.rep_id AND u.rep_id = r.rep_id AND u.sd < 0.01;

SELECT r.chr, r.start, r.end, u.chr, u.start, u.end, d.short_name
FROM disease d, repeats r, unigene u
WHERE d.rep_id = r.rep_id AND r.chr = u.chr AND r.start >= u.start AND r.end <= u.end;

SELECT DISTINCT d.short_name
FROM disease d, repeats r, unigene u
WHERE d.rep_id = r.rep_id AND r.chr = u.chr AND r.start >= u.start AND r.end <= u.end;

SELECT r.rep_id, r.chr, r.start, r.end, r.unit, r.length, t.gene_location, t.pep
FROM repeats r, transcripts t
WHERE t.ens_id = 3525 AND t.rep_id = r.rep_id

SELECT r.length, COUNT(r.length)
FROM repeats r, transcripts t
WHERE r.rep_id = t.rep_id AND r.class = 269 AND t.gene_location = "5utr"
GROUP BY r.length;

SELECT r.length, COUNT(r.length)
FROM repeats r
WHERE r.class = 7596
GROUP BY r.length;

SELECT DISTINCT r.class
FROM rep_class rc, repeats r, disease d
WHERE rc.rep_class_id = r.class AND r.rep_id = d.rep_id;

# How many unstable repeats exist in gene x

SELECT r.rep_id, r.chr, r.start, r.end, r.unit, r.class, t.gene_location, t.pep, e.name, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, transcripts t, ens_db e, ugstats u
WHERE e.name = "ENSG00000157168" AND e.ens_id = t.ens_id AND t.rep_id = r.rep_id AND r.rep_id = u.rep_id AND u.sd > 0;

# Are the repeats statistically significant based on their location within transcripts
SELECT r.class, t.gene_location, count(r.rep_id), avg(length), stddev(length)
FROM repeats r, transcripts t
WHERE r.rep_id = t.rep_id AND r.class = 3355
GROUP BY r.class DESC, t.gene_location;

SELECT t.gene_location, count(r.rep_id), avg(length), stddev(length)
FROM repeats r, transcripts t
WHERE r.rep_id = t.rep_id
GROUP BY t.gene_location;

SELECT count(*)
FROM repeats
WHERE class = 2;

CREATE TABLE distinct_repeat_class
SELECT DISTINCT unit
FROM repeats;1;

# Repeat prioritization

SELECT r.rep_id, r.chr, r.start, r.end, r.unit, r.length, r.pvalue, l.link_id, u.count, u.min, u.max, u.mean, u.sd
FROM repeats r, linkage l, ugstats u
WHERE l.disease = \"SCZ\" AND r.chr = l.chr AND r.start >= l.start AND r.end <= l.end AND r.rep_id = u.rep_id;

SELECT r.rep_id, r.chr, r.start, r.end, r.unit, r.length, r.pvalue, l.link_id, u.count, u.min, u.max, u.mean, u.sd, t.gene_location, t.pep, e.name, e.description, g.tissue, g.call
FROM repeats r, transcripts t, ens_db e, affy a, genenote g, linkage l, ugstats u
WHERE l.disease = "SCZ" AND r.chr = l.chr AND r.start >= l.start AND r.end <= l.end AND r.rep_id = u.rep_id AND r.rep_id = t.rep_id AND t.ens_id = e.ens_id AND e.ens_id = a.ens_id AND a.g_id = g.g_id AND g.tissue = "Brain" AND g.call = "P";