#!/usr/bin/perl
# repeatalyzer.pl
# usage: repeatalyzer.pl trf_cag_build33.out
# Perseus Missirlis - Jan 8, 2004

use strict;
use Bio::EnsEMBL::DBSQL::DBAdaptor;
use DBI;

####################
# Global Variables #
####################

###########################
# Repeat-dwelling classes #
###########################

# ensembl API

my $host                = 'ensembldb.ensembl.org';
my $user                = 'anonymous';
my $db_name             = 'homo_sapiens_core_19_34a';

# DBI

my ($dsn) = "DBI:mysql:schz_db:athena.bcgsc.ca";
my ($user_name) = "schz_rw";
my ($password) = "repeat";
my ($dbh, $sth);
my (@ary);

#######################
# Connect to Database #
#######################

$dbh = DBI->connect ($dsn, $user_name, $password, { RaiseError => 1 });

#######################################
# Ensembl API Variable Initialization #
#######################################

my $db = new Bio::EnsEMBL::DBSQL::DBAdaptor(-host       => $host,
                                            -user       => $user,
                                            -dbname     => $db_name);

my $slice_adaptor = $db->get_SliceAdaptor;

################################
# Insert into build_info table #
################################

#$sth = $dbh->prepare ("INSERT INTO build_info VALUES('$host','$db_name',NOW())");
#$sth->execute ();

##########################################################################
# Read infile specified on the cmd line                                  #
# Read multiple coords of repeat locations from STDIN one line at a time #
##########################################################################

my $chrom;

while (<>) {
  chomp;

if ($_ =~ /chr(\S+)/) {
$chrom = $1;

} elsif ($_ =~ /(\d+)\s+(\d+)\s+(\d+)\s+(\d+\.\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\.\d+\s+(\S+)\s+(\S+)/) {

  # pull out coords of interest
  my $chromStart= $1;
  my $chromEnd = $2;
  my $rptPeriod = $3;
  my $rptSize = $4;
  my $rptConsensus = $5;
  my $rptUnit = $6;
  my $rpt = $7;

print "chrom $chrom chromStart $chromStart chromEnd $chromEnd rptPeriod $rptPeriod repConsensus $rptConsensus rptSize $rptSize rptUnit $rptUnit rpt $rpt\n\n";

my $rep_id = $chrom . "_" . $chromStart . "_" . $chromEnd;

my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart,$chromEnd);
my $rptRegion = $slice->seq;

####################################################################################
# Check to see if repeats detected in UCSC chromosomes have same coords in ensembl #
####################################################################################

if ($rpt eq $rptRegion) {
} else {
print "ERROR: $rep_id: repeats don't match\n\n";
}

###########################################
# Calculate flanking GC values for repeat #
###########################################

my $g; my $c;

# 100

my $slice_left_100 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart-100,$chromStart-1);
my $slice_right_100 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromEnd+1,$chromEnd+100);
my $left_100 = $slice_left_100->seq;
my $right_100 = $slice_right_100->seq;
my $gc_100_seq = $left_100 . $right_100;

$g=0; $c=0; my $gc_length_100 = length($gc_100_seq);
while($gc_100_seq =~ /g/ig){$g++}
while($gc_100_seq =~ /c/ig){$c++}
my $gc_100 = ($g+$c)/$gc_length_100;

# 500

my $slice_left_500 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart-500,$chromStart-1);
my $slice_right_500 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromEnd+1,$chromEnd+500);
my $left_500 = $slice_left_500->seq;
my $right_500 = $slice_right_500->seq;
my $gc_500_seq = $left_500 . $right_500;

$g=0; $c=0; my $gc_length_500 = length($gc_500_seq);
while($gc_500_seq =~ /g/ig){$g++}
while($gc_500_seq =~ /c/ig){$c++}
my $gc_500 = ($g+$c)/$gc_length_500;

# 1000

my $slice_left_1000 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart-1000,$chromStart-1);
my $slice_right_1000 = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromEnd+1,$chromEnd+1000);
my $left_1000 = $slice_left_1000->seq;
my $right_1000 = $slice_right_1000->seq;
my $gc_1000_seq = $left_1000 . $right_1000;

$g=0; $c=0; my $gc_length_1000 = length($gc_1000_seq);
while($gc_1000_seq =~ /g/ig){$g++}
while($gc_1000_seq =~ /c/ig){$c++}
my $gc_1000 = ($g+$c)/$gc_length_1000;

######################
# Insert to gc table #
######################

$sth = $dbh->prepare ("INSERT INTO gc VALUES('$rep_id','$gc_100','$gc_500','$gc_1000')");
                        $sth->execute ();

#############
# Get Slice #
#############

my $n = 0;
my $gene_found = 'n';
my $adder;
my $class_determined = 'n';

print "n is $n   genefound is $gene_found\n\n";

while (($gene_found eq 'n') && ($n < 5)) {

$adder = $n*15000;

my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart - $adder,$chromEnd + $adder);

my $rptRegion = $slice->seq;

############################
# Get all genes from slice #
############################

my $genes = $slice->get_all_Genes;
foreach my $gene(@$genes) {

my $gene_type = $gene->type;

        print "the type of this gene is: " . $gene->type . "\n\n";

if ($gene_type eq 'ensembl') {

$gene_found = 'y';

my $ens_gene_id = $gene->stable_id;

print $ens_gene_id . "\n\n";

#######################
# Link rep_id to gene #
#######################

        $sth = $dbh->prepare ("INSERT INTO genes VALUES('$rep_id','$ens_gene_id')");
        $sth->execute ();

##################################
# Is the gene already in ens_db? #
##################################

my $gene_exists = 'n';
my $statement = "SELECT e.ens_name FROM ens_db e WHERE e.ens_name = \"$ens_gene_id\"\;";
                                                                                                                                                             
$sth = $dbh->prepare($statement);
$sth->execute ();
                                                                                                                                                             
while ( my $href = $sth->fetchrow_hashref ) {
        my $temp_ens = $href->{ens_name};
        if ($ens_gene_id eq $temp_ens) {
        print "$ens_gene_id already exists in the database\n\n";
$gene_exists = 'y';
        }
}

###################################
# Get all Database links for gene #
###################################

#########################################################################
# If the gene doesn't exist in schz_db then collect suppplementary info #
#########################################################################

print "gene_exists is $gene_exists\n\n";

if ($gene_exists eq 'n') {

my $gene_chr = $gene->chr_name;
my $gene_start = $gene->start;
my $gene_end = $gene->end;
my $gene_strand = $gene->strand;
my $slice_start = $slice->chr_start;
my $slice_end = $slice->chr_end;

print "slice_start $slice_start slice_end $slice_end gene_start $gene_start gene_end $gene_end\n\n";

my $true_gene_start = ($slice_start + $gene_start - 1);
my $true_gene_end = ($slice_end + $gene_end);

my $true_strand;
                                                                                                                                                             
        if ($gene_strand == 1) {
                $true_strand = "+";
            }
        elsif ($gene_strand == -1 ) {
                $true_strand = "-";
            }
                                                                                                                                                             
        $sth = $dbh->prepare ("INSERT INTO ens_db VALUES('$ens_gene_id',NULL,'$gene_chr','$true_gene_start','$true_gene_end','$true_strand')");
        $sth->execute ();

if ($gene->is_known) {

        foreach my $link (@{$gene->get_all_DBLinks}) {
                my $database = $link->database;
                my $display_id = $link->display_id;
        if ($database eq 'GO') {
        $display_id =~ s/GO\://;
$sth = $dbh->prepare ("INSERT INTO go VALUES('$ens_gene_id','$display_id')");
        $sth->execute ();
        } elsif ($database eq 'PDB') {
        $sth = $dbh->prepare ("INSERT INTO pdb VALUES('$ens_gene_id','$display_id')");
        $sth->execute ();
        } elsif ($database eq 'MIM') {
        $sth = $dbh->prepare ("INSERT INTO mim VALUES('$ens_gene_id','$display_id')");
        $sth->execute ();
        } elsif ($database =~ /(AFFY_HG_U95[ABCDE]$)/ ) {
        $sth = $dbh->prepare ("INSERT INTO affy VALUES('$ens_gene_id','$display_id')");
        $sth->execute ();
        } elsif ($database eq 'HUGO') {
        $sth = $dbh->prepare ("UPDATE ens_db SET name='$display_id' WHERE ens_name='$ens_gene_id'");
        $sth->execute ();
        }

}
}
}


print "n is $n\n\n";

if ($n == 0) {

                my $transcripts = $gene->get_all_Transcripts;
                foreach my $transcript(@$transcripts) {

print $transcript->stable_id . "\n\n";

                #################################
                # See if repeat in 5' or 3' UTR #
                #################################

print "class_determined before utr tests is $class_determined\n\n";

my $five_utr;
my $three_utr;

if ($transcript->five_prime_utr) {
print "transcript " . $transcript . "has a 5UTR\n\n";
if ($transcript->five_prime_utr->seq) {
print "transcript " . $transcript->stable_id . " has a 5UTR and has sequence :\n\n" . $transcript->five_prime_utr->seq . "\n\n";
$five_utr = $transcript->five_prime_utr->seq;

                        if (($five_utr =~ /($rptRegion)/g) && ($class_determined eq 'n')) {
                        $class_determined = 'y';
                        $sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize','$fiver')");
                        $sth->execute ();
}
}

print "class determined after 5UTR $class_determined\n\n";

} elsif ($transcript->three_prime_utr) {
                print "transcript " . $transcript . "has a 3UTR\n\n";
                if ($transcript->three_prime_utr->seq) {
                print "transcript " . $transcript->stable_id . " has a 3UTR and has sequence :\n\n" . $transcript->three_prime_utr->seq . "\n\n";
                $three_utr = $transcript->three_prime_utr->seq;
                                                                                                                                                             
                        if (($three_utr =~ /($rptRegion)/g) && ($class_determined eq 'n')) {
                        $class_determined = 'y';
                        $sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize','$threer')");
                        $sth->execute ();

}
}
print "class determined after 3UTR $class_determined\n\n";
}

print "$ens_gene_id after utr analysis is class-determined? : $class_determined\n\n";

my %exon_structure;
my $exon_start;
my $exon_seq;

if ($class_determined eq 'n') {

########################################
# Populate hash with exon co-ordinates #
########################################

         my $exons = $gene->get_all_Exons ;
foreach my $exon(@$exons) {
$exon_start = $exon->start;
$exon_seq = $exon->seq->seq;
$exon_structure{$exon_start} = $exon_seq;
}

############################################################
# Generate CDS from exon structure (usually includes UTRs) #
############################################################

my $cds;

foreach my $k (sort { $a <=> $b } (keys %exon_structure)) {
    $cds = $cds . $exon_structure{$k};
}

# print "this is the total exon :\n\n$cds\n\n";

if ($cds =~ /($rptRegion)/g) {
                        $class_determined = 'y';

$sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize','$coder')");
                        $sth->execute ();
        } else {
                        $class_determined = 'y';
$sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize','$introner')");
                        $sth->execute ();
}
}
print "end of loop 0"; }
print "end of loop 1"; }

}

print "end of loop 2";}

$n++ }

if (($n > 1) && ($n < 5)) {

$sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize','$adder')");
$sth->execute ();

} elsif ($n == 5) {
$sth = $dbh->prepare ("INSERT INTO repeats VALUES('$rep_id','$chrom','$chromStart','$chromEnd','$rptPeriod','$rptUnit','$rptRegion','$rptSize',NULL)");
$sth->execute ();
}
}
}

exit;
