Appendix C:  Interacting with and creating the 'gems_cis' database

In order to access the database, a MySQL client must be installed on your machine. 
To connect to the schz_db database externally use at the command line:

$ mysql -h athena -u schz_rw -p schz_db
Password:  repeat

You should now be connected with full administrator (i.e. read and write) powers.

Note:  the following commands are stored in a separate file entitled 'gems.sql'. 
Alternatively, they could simply be cut and pasted out of this document.

Re-populating the Database:  Deleting the tables

WARNING:  This will delete all data collected so far by the database!

If you want to re-run repeatalyzer.pl and re-populate the database you must delete
all the tables currently in the database with these commands:

  DROP TABLE repeats;
  DROP TABLE build_info;
  DROP TABLE transcripts;
  DROP TABLE gc;
  DROP TABLE ens_db;
  DROP TABLE go;
  DROP TABLE pdb;
  DROP TABLE mim;
  DROP TABLE affy;
  DROP TABLE linkage;

  DROP TABLE genenote;

Re-populating the Database:  Creating the tables

You must now re-create all the tables you just deleted so that repeatalyzer.pl can
insert data into the expected fields.  Execute the following commands to do this:

CREATE TABLE build_info
(
        ens_db VARCHAR(50) NOT NULL PRIMARY KEY,
        db_name VARCHAR(50) NOT NULL,
        date_run DATETIME
);

CREATE TABLE unigene
(
      ug_id INT auto_increment NOT NULL PRIMARY KEY,
      ug_cluster INT NOT NULL,
      ug_seq VARCHAR(15),
      ug_chr VARCHAR(2),
      ug_start INT UNSIGNED,
      ug_end INT UNSIGNED

);

CREATE INDEX location ON unigene (ug_cluster, ug_seq, ug_chr, ug_start, ug_end);

CREATE TABLE repeats
(
	  rep_id VARCHAR(50) PRIMARY KEY,
        chr VARCHAR(4),
        start INT UNSIGNED,
        end INT UNSIGNED,
	  period TINYINT UNSIGNED,
        unit VARCHAR(16),
        seq VARCHAR(255),
        length INT UNSIGNED
);

CREATE TABLE transcripts
(
	  ts_id INT auto_increment NOT NULL PRIMARY KEY,
        rep_id VARCHAR(50) NOT NULL,
	  ens_ts VARCHAR(15),
        gene_location VARCHAR(20),
        ens_name VARCHAR(15) NOT NULL
);

CREATE INDEX location ON transcripts (gene_location);
CREATE INDEX ts ON transcripts (ens_ts);
CREATE INDEX ens_name ON transcripts (ens_name);

CREATE TABLE gc
(
        rep_id VARCHAR(50) NOT NULL PRIMARY KEY,
        100_bp DECIMAL(7,6) NOT NULL,
        500_bp DECIMAL(7,6) NOT NULL,
        1000_bp DECIMAL(7,6) NOT NULL
);

CREATE TABLE ens_db
(
        ens_name VARCHAR(15) NOT NULL PRIMARY KEY,
        name VARCHAR(15) NULL,
	  description TEXT NULL,
        chr CHAR(2),
	  start INT UNSIGNED,
	  end INT UNSIGNED,
        strand CHAR(1)
);

CREATE TABLE go
(
	  go_id INT auto_increment NOT NULL PRIMARY KEY,
        ens_name VARCHAR(15) NOT NULL,
        go_value VARCHAR(50) NOT NULL
);

CREATE TABLE pdb
(
	  pdb_id INT auto_increment NOT NULL PRIMARY KEY,
        ens_name VARCHAR(15) NOT NULL,
        domain VARCHAR(20) NOT NULL
);

CREATE TABLE mim
(
	  mim_id INT auto_increment NOT NULL PRIMARY KEY,
        ens_name VARCHAR(15) NOT NULL,
        mim_value VARCHAR(20) NOT NULL
);

CREATE TABLE affy
(
	  affy_id INT auto_increment NOT NULL PRIMARY KEY,
        ens_name VARCHAR(15) NOT NULL,
        id_ref VARCHAR(15) NOT NULL
);

CREATE INDEX ens_name ON affy (ens_name);
CREATE INDEX id_ref ON affy (id_ref);

CREATE TABLE linkage
(
        band VARCHAR(10) NOT NULL,
        chr CHAR(2) NOT NULL,
        start INT UNSIGNED NOT NULL,
        end INT UNSIGNED NOT NULL,
        unit VARCHAR(16) NOT NULL,
        paper TEXT NOT NULL,
        lod VARCHAR(4) NOT NULL
);









CREATE TABLE genenote
(
        id_ref VARCHAR(15) NOT NULL,
        value DECIMAL(10,1) NOT NULL,
        call CHAR(1) NOT NULL,
	  tissue VARCHAR(15) NOT NULL,
        array CHAR(1) NOT NULL,
	  number CHAR(4) NOT NULL
);

CREATE INDEX id_ref ON genenote (id_ref);
CREATE INDEX tissue ON genenote (tissue);
CREATE INDEX call ON genenote (call);
