#!/usr/bin/perl
# test.pl
# usage: test.pl chr1.dat
# Perseus Missirlis - Jan 16, 2004

use strict;
use Bio::EnsEMBL::DBSQL::DBAdaptor;

#######################################
# Ensembl API Variable Initialization #
#######################################

my $host                = 'ensembldb.ensembl.org';
my $user                = 'anonymous';
my $db_name             = 'homo_sapiens_core_19_34a';

# ensembl API connection                                                                                                                                                            
my $db = new Bio::EnsEMBL::DBSQL::DBAdaptor(-host       => $host,
                                            -user       => $user,
                                            -dbname     => $db_name);

my $slice_adaptor = $db->get_SliceAdaptor;

my $chrom;

while (<>) {
  chomp;

if ($_ =~ /chr(\S+)/) {
        $chrom = $1;

print " this is chrom $chrom\n\n";

} elsif ($_ =~ /(\d+)\s+(\d+)\s+(\d+)\s+(\d+\.\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+\.\d+\s+(\S+)\s+(\S+)/) {
  
# pull out coords of interest
  my $chromStart= $1;
  my $chromEnd  = $2;
  my $rptPeriod = $3;
  my $rptSize   = $4;
  my $rptConsensus = $5;
  my $rptUnit   = $6;
  my $rpt       = $7;
  my $rptLength = length $rpt;

print "chrom $chrom chromStart $chromStart chromEnd $chromEnd rptPeriod $rptPeriod repConsensus $rptConsensus rptSize $rptSize rptUnit $rptUnit rpt $rpt rptLength $rptLength\n\n";

my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$chromStart,$chromEnd);
my $rptRegion = $slice->seq;

my $gene_found;

# test co-ords with HD
# 5utr-ncs-boundary (-800,-250)
# 5utr (-250,-200)
# 5utr-cds (-100,1200)
# 3utr-ncs-boundary (169000,171000)
# 3utr = (166000,169000)
# 3out of bounds = (-750,-500)
# 5out of bounds = (177000,178000)

my $repStart = 0;
my $repEnd = $rptLength;

############################
# Get all genes from slice #
############################

my $genes = $slice->get_all_Genes;
        foreach my $gene(@$genes) {
        my $gene_type = $gene->type;
        print "the type of this gene is: " . $gene->type . "\n\n";
        if ($gene_type eq 'ensembl') {
        $gene_found = 'y';
        my $ens_gene_id = $gene->stable_id;
my $strander = $gene->strand;

# print "strand is $strander\n";

#        print $ens_gene_id . "\n\n";

                my $transcripts = $gene->get_all_Transcripts;
                foreach my $transcript(@$transcripts) {

                print $transcript->stable_id . "\n\n";
                my $coding_start = $transcript->coding_start;
                my $coding_end = $transcript->coding_end;

                print "coding start is $coding_start and coding end is $coding_end \n\n";

my %exon_structure;

         my $exons = $transcript->get_all_Exons ;
                foreach my $exon(@$exons) {
                        my $exon_start     = $exon->start;
                        my $exon_end       = $exon->end;
                        my $exon_end       = $exon->end;
                        my $exon_seq       = $exon->seq->seq;
#                        print "exon start is $exon_start and exon end is $exon_end with seq\n\n$exon_seq\n\n";

                        ########################################
                        # Populate hash with exon co-ordinates #
                        ########################################

                        $exon_structure{$exon_start} = $exon_end;

}

                                foreach my $k (sort { $a <=> $b } (keys %exon_structure)) {
                                        }

my %five_utr; my %cds; my %three_utr;

foreach my $k (sort { $a <=> $b } (keys %exon_structure)) {
#    print "k is $k next one $exon_structure{$k} \n";
    if (($k < $coding_start) && ($exon_structure{$k} < $coding_start)) {
print "these are 5UTR $k $exon_structure{$k}\n";
$five_utr{$k} = $exon_structure{$k};
    } elsif (($k < $coding_start) && ($exon_structure{$k} > $coding_start)) {
        print "these are 5UTR $k $coding_start, followed by this is CDS $coding_start $exon_structure{$k}\n";
        $five_utr{$k} = $coding_start;
$cds{$coding_start} = $exon_structure{$k};
    } elsif (($k > $coding_start) && ($exon_structure{$k} < $coding_end)) {
        print "these are CDS $k $exon_structure{$k}\n";
        $cds{$k} = $exon_structure{$k};
    } elsif (($k < $coding_end) && ($exon_structure{$k} > $coding_end)) {
        print "these are 3UTR $coding_end $exon_structure{$k}, followed by this is CDS $k $coding_end\n";
$cds{$k} = $coding_end;
        $three_utr{$coding_end} = $exon_structure{$k};
    } elsif (($k > $coding_end) && ($exon_structure{$k} > $coding_end)) {
        print "these are 3UTR $k $exon_structure{$k}\n";
        $three_utr{$k} = $exon_structure{$k};
    }
}

if ($strander == -1) {
    my %temp = %three_utr;
    %three_utr = %five_utr;
    %five_utr = %temp;
}

my $min_5utr;
my $max_5utr;

print "before 5utr loop\n\n";

my $x=0;

foreach my $k (sort { $a <=> $b } (keys %five_utr)) {
    print "in 5utr $k $five_utr{$k}\n";

    if ($x == 0) {
$min_5utr = $k;
$max_5utr = $five_utr{$k};
    } elsif ($x > 0) {
if ($k < $min_5utr) {
    $min_5utr = $k;
    print "this is the min5utr $min_5utr\n\n";
} elsif ($five_utr{$k} > $max_5utr) {
    $max_5utr = $five_utr{$k};
    print "this is the max5utr $max_5utr\n\n";
}
    }
$x++;
}

print "min5utr is $min_5utr max5utr is $max_5utr and cycles is $x\n\n";

my $x=0;

my $min_cds;
my $max_cds;

foreach my $k (sort { $a <=> $b } (keys %cds)) {
#    print "in cds $k $cds{$k}\n";
    if ($x == 0) {
        $min_cds = $k;
        $max_cds = $cds{$k};
    } elsif ($x > 0) {
        if ($k < $min_cds) {
            $min_cds = $k;
#            print "this is the mincds $min_cds\n\n";
        } elsif ($cds{$k} > $max_cds) {
            $max_cds = $cds{$k};
#            print "this is the maxcds $max_cds\n\n";
        }
    }
$x++;
}

print "this is min cds $min_cds\n\nthis is max cds $max_cds\n\nthis is number of cycles $x\n\n";

my $min_3utr;
my $max_3utr;

my $x=0;

foreach my $k (sort { $a <=> $b } (keys %three_utr)) {
    print "in 3utr $k $three_utr{$k}\n";

    if ($x == 0) {
        $min_3utr = $k;
        $max_3utr = $three_utr{$k};
    } elsif ($x > 0) {
        if ($k < $min_3utr) {
            $min_3utr = $k;
            print "this is the min5utr $min_3utr\n\n";
        } elsif ($three_utr{$k} > $max_3utr) {
            $max_3utr = $three_utr{$k};
            print "this is the max3utr $max_3utr\n\n";
        }
    }
$x++;
}

print "this is absolute min 3utr $min_3utr, max $max_3utr, and cycles $x\n\n";

my $found = 'n';
my $location;

############################################
# Where in the gene is the repeat located? #
############################################

############################################
# Is the repeat within the 5UTR boundaries #
############################################

if (($repStart >= $min_5utr) && ($repEnd <= $max_5utr)) {
    foreach my $k (sort { $a <=> $b } (keys %five_utr)) {
    if (($repStart >= $k) && ($repEnd <= $five_utr{$k})) {
$location = "5utr";
$found = 'y';
    } elsif ((($repStart < $k) && ($repEnd >= $k)) || (($repStart <= $five_utr{$k}) && ($repEnd > $five_utr{$k}))) {
$location = "5utr-intron-boundary";
$found = 'y';
}
    } if ($found eq 'n') {
$location = "5utr-intron";
$found = 'y';
    }
}

###########################################
# Is the repeat within the CDS boundaries #
###########################################

elsif (($repStart >= $coding_start) && ($repEnd <= $coding_end)) {
    foreach my $k (sort { $a <=> $b } (keys %cds)) {
    if (($repStart >= $k) && ($repEnd <= $cds{$k})) {
        $location = "exon";
$found = 'y';
    } elsif ((($repStart < $k) && ($repEnd > $k)) || (($repStart < $cds{$k}) && ($repEnd > $cds{$k}))) {
        $location = "intron-exon boundary";
$found = 'y';
}
    } if ($found eq 'n') {
$location = "intron";
        $found = 'y';
    }
}

############################################
# Is the repeat within the 3UTR boundaries #
############################################

elsif (($repStart >= $min_3utr) && ($repEnd <= $max_3utr)) {
    foreach my $k (sort { $a <=> $b } (keys %three_utr)) {
    if (($repStart >= $k) && ($repEnd <= $three_utr{$k})) {
        $location = "3utr";
$found = 'y';
    } elsif ((($repStart < $k) && ($repEnd >= $k)) || (($repStart <= $three_utr{$k}) && ($repEnd > $three_utr{$k}))) {
        $location = "3utr-intron-boundary";
$found = 'y';
        }
    } if ($found eq 'n') {
$location = "3utr-intron";
        $found = 'y';
    }
}

#########################################
# Is the repeat on the 5UTR boundaries? #
#########################################

elsif (($repStart < $min_5utr) && ($repEnd >= $min_5utr)) {
    $location = "5utr-ncs-boundary";
    $found = 'y';
} elsif (($repStart >= $min_5utr) && ($repEnd <= $coding_end)) {
    $location = "5utr-cds";
    $found = 'y';
} elsif (($repStart <= $coding_end) && ($repEnd >= $min_3utr)) {
    $location = "3utr-cds";
    $found = 'y';
} elsif (($repStart <= $max_3utr) && ($repEnd > $max_3utr)) {
    $location = "3utr-ncs-boundary";
    $found = 'y';
} elsif ((($repStart < $min_5utr) && ($repEnd < $min_5utr)) || (($repStart > $max_3utr) && ($repEnd > $max_3utr))) {
    print "error, repeat doesn't seem to be within gene boundaries\n\n";
    }

if (($found eq 'y') && ($location)) {
    print "location of repeat found: $found, location: $location\n\n";
} elsif ($found eq 'n') {
    print "error, repeat not within gene boundaries\n\n";
}

foreach my $k (sort { $a <=> $b } (keys %five_utr)) {
#    print "in 5utr $k $five_utr{$k}\n";
    }

foreach my $k (sort { $a <=> $b } (keys %cds)) {
#    print "in cds $k $cds{$k}\n";
}

foreach my $k (sort { $a <=> $b } (keys %three_utr)) {
#    print "in 3utr $k $three_utr{$k}\n";
    }

if ($transcript->five_prime_utr->seq) {
#print "transcript " . $transcript->stable_id . " has a 5UTR and has sequence :\n\n" . $transcript->five_prime_utr->seq . "\n\n";
}

print "5UTR from my co-ordinates\n";
foreach my $k (sort { $a <=> $b } (keys %five_utr)) {
#    print "in 5utr $k $five_utr{$k}\n";
my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$repStart+$k-1,$repEnd+$five_utr{$k}-$rptLength-1);
#print $slice->seq . "\n\n";
}

if ($transcript->three_prime_utr->seq) {
#print "transcript " . $transcript->stable_id . " has a 3UTR and has sequence :\n\n" . $transcript->three_prime_utr->seq . "\n\n";
}

print "3UTR from my co-ordinates\n";
foreach my $k (sort { $a <=> $b } (keys %three_utr)) {
#    print "in 3utr $k $three_utr{$k}\n";
my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$repStart+$k,$repEnd+$three_utr{$k}-$rptLength);
#print $slice->seq . "\n\n";
    }

print "CDS from my co-ordinates\n";
foreach my $k (sort { $a <=> $b } (keys %cds)) {
#    print "in 3utr $k $three_utr{$k}\n";
my $slice = $slice_adaptor->fetch_by_chr_start_end($chrom,$repStart+$k-1,$repEnd+$cds{$k}-$rptLength);
#print $slice->seq . "\n\n";
    }

# my $coding_region_start = $transcript->coding_region_start;
# my $coding_region_end = $transcript->coding_region_end;

# print "coding start is $coding_region_start and coding end is $coding_region_end \n\n";
}
    }
}
    }
}
exit;
